"""Static pricing data for image generation models."""

from pricetoken.types import ImageModelPricing

STATIC_IMAGE_PRICING: list[ImageModelPricing] = [
    # OpenAI — DALL-E
    ImageModelPricing(
        model_id="dall-e-3-standard-1024",
        provider="openai",
        display_name="DALL-E 3 Standard 1024",
        price_per_image=0.040,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="dall-e-3-hd-1024",
        provider="openai",
        display_name="DALL-E 3 HD 1024",
        price_per_image=0.080,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="dall-e-3-standard-1792",
        provider="openai",
        display_name="DALL-E 3 Standard 1792",
        price_per_image=0.080,
        price_per_megapixel=None,
        default_resolution="1792x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="dall-e-3-hd-1792",
        provider="openai",
        display_name="DALL-E 3 HD 1792",
        price_per_image=0.120,
        price_per_megapixel=None,
        default_resolution="1792x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="dall-e-2-1024",
        provider="openai",
        display_name="DALL-E 2 1024",
        price_per_image=0.020,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # OpenAI — GPT Image
    ImageModelPricing(
        model_id="gpt-image-1-low",
        provider="openai",
        display_name="GPT Image 1 Low",
        price_per_image=0.011,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="gpt-image-1-medium",
        provider="openai",
        display_name="GPT Image 1 Medium",
        price_per_image=0.042,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="gpt-image-1-high",
        provider="openai",
        display_name="GPT Image 1 High",
        price_per_image=0.167,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Google — Imagen
    ImageModelPricing(
        model_id="imagen-3",
        provider="google",
        display_name="Imagen 3",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="imagen-4-fast",
        provider="google",
        display_name="Imagen 4 Fast",
        price_per_image=0.02,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="imagen-4-standard",
        provider="google",
        display_name="Imagen 4 Standard",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="imagen-4-ultra",
        provider="google",
        display_name="Imagen 4 Ultra",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="ultra",
        max_resolution="2048x2048",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Stability AI
    ImageModelPricing(
        model_id="sd-3.5-large",
        provider="stability",
        display_name="SD 3.5 Large",
        price_per_image=0.065,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "webp"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="sd-3.5-large-turbo",
        provider="stability",
        display_name="SD 3.5 Large Turbo",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "webp"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="stable-image-ultra",
        provider="stability",
        display_name="Stable Image Ultra",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="ultra",
        max_resolution="2048x2048",
        supported_formats=["png", "webp"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="stable-image-core",
        provider="stability",
        display_name="Stable Image Core",
        price_per_image=0.03,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "webp"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Black Forest Labs — FLUX.1 series
    ImageModelPricing(
        model_id="flux-1.1-pro",
        provider="bfl",
        display_name="FLUX 1.1 Pro",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2024-10-02",
    ),
    ImageModelPricing(
        model_id="flux-1.1-pro-ultra",
        provider="bfl",
        display_name="FLUX 1.1 Pro Ultra",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="hd",
        max_resolution="2048x2048",
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2024-11-06",
    ),
    ImageModelPricing(
        model_id="flux-1.1-pro-raw",
        provider="bfl",
        display_name="FLUX 1.1 Pro Raw",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2024-11-06",
    ),
    ImageModelPricing(
        model_id="flux-1-kontext-pro",
        provider="bfl",
        display_name="FLUX 1 Kontext Pro",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-05-29",
    ),
    ImageModelPricing(
        model_id="flux-1-kontext-max",
        provider="bfl",
        display_name="FLUX 1 Kontext Max",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-05-29",
    ),
    ImageModelPricing(
        model_id="flux-1-fill-pro",
        provider="bfl",
        display_name="FLUX 1 Fill Pro",
        price_per_image=0.05,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2024-11-01",
    ),
    # Black Forest Labs — FLUX.2 series (megapixel-based, price = first MP flat rate)
    ImageModelPricing(
        model_id="flux-2-klein-4b",
        provider="bfl",
        display_name="FLUX 2 Klein 4B",
        price_per_image=0.014,
        price_per_megapixel=0.001,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2026-01-15",
    ),
    ImageModelPricing(
        model_id="flux-2-klein-9b",
        provider="bfl",
        display_name="FLUX 2 Klein 9B",
        price_per_image=0.015,
        price_per_megapixel=0.001,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2026-01-15",
    ),
    ImageModelPricing(
        model_id="flux-2-pro",
        provider="bfl",
        display_name="FLUX 2 Pro",
        price_per_image=0.03,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-11-25",
    ),
    ImageModelPricing(
        model_id="flux-2-flex",
        provider="bfl",
        display_name="FLUX 2 Flex",
        price_per_image=0.05,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-11-25",
    ),
    # Amazon — Nova Canvas
    ImageModelPricing(
        model_id="nova-canvas-standard-1024",
        provider="amazon",
        display_name="Nova Canvas Standard 1024",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="nova-canvas-premium-1024",
        provider="amazon",
        display_name="Nova Canvas Premium 1024",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="nova-canvas-standard-2048",
        provider="amazon",
        display_name="Nova Canvas Standard 2048",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="standard",
        max_resolution="2048x2048",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="nova-canvas-premium-2048",
        provider="amazon",
        display_name="Nova Canvas Premium 2048",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="hd",
        max_resolution="2048x2048",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Recraft
    ImageModelPricing(
        model_id="recraft-v4-raster",
        provider="recraft",
        display_name="Recraft V4 Raster",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "svg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="recraft-v4-vector",
        provider="recraft",
        display_name="Recraft V4 Vector",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["svg"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Mistral
    ImageModelPricing(
        model_id="mistral-flux-pro-ultra",
        provider="mistral",
        display_name="Mistral FLUX Pro Ultra",
        price_per_image=0.10,
        price_per_megapixel=None,
        default_resolution="2048x2048",
        quality_tier="ultra",
        max_resolution="2048x2048",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Bytedance
    ImageModelPricing(
        model_id="seedream-4.5",
        provider="bytedance",
        display_name="Seedream 4.5",
        price_per_image=0.035,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # fal.ai
    ImageModelPricing(
        model_id="fal-recraft-v3",
        provider="fal",
        display_name="fal Recraft V3",
        price_per_image=0.02,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-flux-1-pro",
        provider="fal",
        display_name="fal FLUX 1 Pro",
        price_per_image=0.025,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-flux-2-pro",
        provider="fal",
        display_name="fal FLUX 2 Pro",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-ideogram-v2",
        provider="fal",
        display_name="fal Ideogram V2",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-sd3",
        provider="fal",
        display_name="fal SD3",
        price_per_image=0.035,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # Ideogram
    ImageModelPricing(
        model_id="ideogram-v3",
        provider="ideogram",
        display_name="Ideogram V3",
        price_per_image=0.05,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="ideogram-v3-turbo",
        provider="ideogram",
        display_name="Ideogram V3 Turbo",
        price_per_image=0.03,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
    # xAI
    ImageModelPricing(
        model_id="aurora-grok-2-image",
        provider="xai",
        display_name="Aurora Grok 2 Image",
        price_per_image=0.07,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        last_updated=None,
        launch_date="2025-01-15",
    ),
]
